#
# spec file for package python-futurist
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-futurist
Version:        3.0.0
Release:        2.1
Summary:        Useful additions to futures, from the future.
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/futurist
Source0:        https://files.pythonhosted.org/packages/source/f/futurist/futurist-3.0.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-PrettyTable
BuildRequires:  python3-Sphinx
BuildRequires:  python3-eventlet
BuildRequires:  python3-openstackdocstheme
BuildRequires:  python3-oslotest
BuildRequires:  python3-stestr
BuildRequires:  python3-testscenarios
BuildArch:      noarch

%description
Useful additions to futures, from the future.

%package -n python3-futurist
Summary:        Useful additions to futures, from the future.

%description -n python3-futurist
Useful additions to futures, from the future.

This package contains the Python 3.x module.

%prep
%autosetup -p1 -n futurist-3.0.0
%py_req_cleanup

%build
%{py3_build}

# generate html docs
PBR_VERSION=3.0.0 %sphinx_build -b html doc/source doc/build/html
# remove the sphinx-build leftovers
rm -r doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}

%check
%{openstack_stestr_run}

%files -n python3-futurist
%doc doc/build/html README.rst
%license LICENSE
%{python3_sitelib}/futurist
%{python3_sitelib}/futurist-*-py?.*.egg-info

%changelog
* Mon Sep 30 2024 Steve Kowalik <steven.kowalik@suse.com>
- Drop monotonic BuildRequires, unneeded since 2.2.0.
* Fri May 10 2024 cloud-devel@suse.de
- update to version 3.0.0
  - tox: Replace whitelist_externals
  - coveragerc: Remove non-existent path
  - Revert "Moves supported python runtimes from version 3.8 to 3.10"
  - Update python classifier in setup.cfg
  - Drop python3.6/3.7 support in testing runtime
  - Add py39 package metadata
  - Bump hacking
  - Moves supported python runtimes from version 3.8 to 3.10
* Sat May 14 2022 cloud-devel@suse.de
- update to version 2.4.1
  - Update CI to use unversioned jobs template
  - trivial: Remove unnecessary 'coding' lines
  - Remove six
  - Remove pbr from requirements.txt
  - tox: Trivial cleanups
* Mon Dec  6 2021 cloud-devel@suse.de
- update to version 2.4.0
  - remove unicode from code
  - Use TOX_CONSTRAINTS_FILE
  - setup.cfg: Replace dashes with underscores
  - trivial: Bump hacking to 4.x
  - Move flake8 as a pre-commit local target.
  - pre-commit: Lower flake8 version
  - Use py3 as the default runtime for tox
  - Update master for stable/victoria
  - Uncap PrettyTable
  - Remove lower-constraints remnants
  - Add Python3 wallaby unit tests
  - Adding pre-commit
  - Dropping lower constraints testing
  - ignore reno generated artifacts
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 2.3.0
  - Remove monotonic usage
  - Remove unnecessary blockquote in release notes
  - [goal] Migrate testing to ubuntu focal
  - Add py38 package metadata
  - Bump default tox env from py37 to py38
  - Switch to newer openstackdocstheme and reno versions
  - drop mock from lower-constraints
  - Update master for stable/ussuri
  - Use unittest.mock instead of third party mock
  - Remove translation sections from setup.cfg
  - Add Python3 victoria unit tests
* Tue May 12 2020 cloud-devel@suse.de
- update to version 2.1.1
  - Make PrettyTable optional
  - Switch to Ussuri jobs
  - Update master for stable/train
  - Update the constraints url
  - Fix Calling waiters.wait_for_any() blocks if future has called Condition.wait()
  - Sync Sphinx requirement
  - [ussuri][goal] Drop python 2.7 support and testing
  - Add release notes link to README
  - Bump the openstackdocstheme extension to 1.20
  - Update hacking for Python3
* Sat Mar 14 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only builds
* Thu Oct 17 2019 cloud-devel@suse.de
- update to version 1.9.0
  - Update master for stable/stein
  - OpenDev Migration Patch
  - Use opendev repository
  - Dropping the py35 testing
  - Add Python 3 Train unit tests
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 1.8.1
  - fix tox python3 overrides
  - Add blueprints notes link to README
  - Use template for lower-constraints
  - Trivial: Update pypi url to new url
  - Change openstack-dev to openstack-discuss
  - import zuul job settings from project-config
  - Update reno for stable/rocky
  - Only install monotonic on python2
  - Don't quote {posargs} in tox.ini
  - Follow the new PTI for document build
  - Remove the duplicated word
  - add lib-forward-testing-python3 test job
  - add python 3.6 unit test job
  - Switch to stestr
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 1.7.0
  - set default python to python3
  - clean up test job configuration
  - Update reno for stable/queens
  - Update links in README
  - fix lower constraints and uncap eventlet
  - Updated from global requirements
  - add lower-constraints job
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Tue Jan 23 2018 tbechtold@suse.com
- Convert to singlespec
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 1.6.0
  - Improving cover and docs testenv
  - Fix jitter strategies
  - Begin adding our own thread pool executor
  - Remove 'smart' idleness check
  - Avoid tox_install.sh for constraints support
  - Improve get optimal count of max_worker for pool
  - Update reno for stable/ocata
  - Fix time related check in rejection test
  - Eliminate unneccessary patching in GreenFuture
  - Add what the watcher watches to the watcher as a property
  - Remove discover from test-requirements
  - Typo fix: arbitary => arbitrary
  - Add Constraints support
  - Add reno for release notes management
  - Show team and repo badges on README
  - Don't include openstack/common in flake8 exclude list
  - Introducing NeverAgain functionality for periodics
  - Add re-raising SystemExit exception
  - Add Python 3.5 classifier and venv
  - turn on warning-is-error in doc build
  - Switch from oslosphinx to openstackdocstheme
  - Update .gitignore
  - Do not check spacing if periodic disabled
  - Fix 'on_failure' param not be used
  - replace _callables by _works
  - The python 3.4 support is removed
  - rearrange existing documentation to fit the new standard layout
  - Use prettytable to show pretty schedule/active/planned time table
  - Removes unnecessary utf-8 coding
  - Improve doctest and doc8 test
  - Update homepage with developer documentation page
  - Update reno for stable/pike
  - Remove setting of version/release from releasenotes
  - Reduce/remove duplication in run functions
  - Remove link to modindex
  - Update URLs in documents according to document migration
  - Updated from global requirements
  - Expose underlying timeout error
* Sun Feb 28 2016 dmueller@suse.com
- update to 0.13.0:
  * Single quote the callables name (when submission errors
  * Updated from global requirements
  * Reschedule failed periodic tasks after a short delay
  * Fix wrong comparison in reject_when_reached
  * Updated from global requirements
  * Ensure all futures have completed before run returns
  * Allow PeriodicWorker to skip executor shutdown in case of a preexisting executor
  * Expose underlying futures.CancelledError
  * Updated from global requirements
  * Modification of the example code
  * PeriodicWorker.create to accept arguments for periodic tasks
  * Handle exceptions from executor.submit in PeriodicWorker
  * Add periodics.is_periodic to check if object is a periodic task
  * py26/py33 are no longer supported by Infra's CI
* Mon Jan 11 2016 bwiedemann@suse.com
- Update to version 0.9.0
  * Allow for providing different run work sync functions
  * Have the executor stats object repr look like the watcher repr
  * Add useful watcher '__repr__' function
  * Some minor refactoring and comment/note addition
  * No need for Oslo Incubator Sync
  * Move most of green helper classes -> '_green.py'
  * Add 'enabled' parameter to @periodic decorator
  * Remove green worker reference to its executor
  * Change ignore-errors to ignore_errors
  * Activate pep8 check that _ is imported
  * Handle the case where 0.199 is provided as runtime
  * Just use a deque vs reverse pushing/popping
  * Ensure new entry in immediates gets processed during wait(s)
* Wed Sep  9 2015 tbechtold@suse.com
- update to 0.5.0:
  * Updated from global requirements
  * Provide a thread differentiation attribute on executors
- Adjust Requires according to requirements.txt
* Tue Aug  4 2015 tbechtold@suse.com
- update to 0.3.0:
  * Updated from global requirements
  * Allow providing a callback to certain executors to reject new work
  * Disallow running 'start' twice
  * Allow for providing custom 'on_failure' callbacks
  * Delegate failure capturing to a object that is returned on run
  * Move doc8 to being a normal test requirement in test-requirements.txt
  * Ensure doctesting and doc8 testing done in py27 env
  * Updated from global requirements
* Tue Jul 21 2015 tbechtold@suse.com
- Initial packaging
